@@ -3,7 +3,7 @@
 /*                  This file is part of the class library                   */
 /*       SoPlex --- the Sequential object-oriented simPlex.                  */
 /*                                                                           */
-/*  Copyright (c) 1996-2023 Zuse Institute Berlin (ZIB)                      */
+/*  Copyright (c) 1996-2026 Zuse Institute Berlin (ZIB)                      */
 /*                                                                           */
 /*  Licensed under the Apache License, Version 2.0 (the "License");          */
 /*  you may not use this file except in compliance with the License.         */
@@ -132,19 +132,16 @@ public:
    {
       T* newelem = create(newkey);
 
-      assert(newelem != 0);
+      assert(newelem != nullptr);
 
       *newelem = item;
    }
    /// adds element \p item.
-   /**@return 0 on success and non-zero, if an error occured.
-    */
    void add(const T& item)
    {
       T* newelem = create();
 
-
-      assert(newelem != 0);
+      assert(newelem != nullptr);
 
       *newelem = item;
    }
@@ -310,7 +307,7 @@ public:
    /// remove \p n elements given by \p keys and \p perm.
    void remove(const DataKey* keys, int n, int* perm)
    {
-      assert(perm != 0);
+      assert(perm != nullptr);
 
       for(int i = num() - 1; i >= 0; --i)
          perm[i] = i;
@@ -329,7 +326,7 @@ public:
    /// remove \p n elements given by \p nums and \p perm.
    void remove(const int* nums, int n, int* perm)
    {
-      assert(perm != 0);
+      assert(perm != nullptr);
 
       for(int i = num() - 1; i >= 0; --i)
          perm[i] = i;
@@ -492,7 +489,7 @@ public:
    ptrdiff_t reMax(int newmax = 0)
    {
       int i;
-      Item* newMem = 0;
+      Item* newMem = nullptr;
       newmax = (newmax < size()) ? size() : newmax;
 
       int* lastfree = &firstfree;
@@ -534,20 +531,20 @@ public:
 #ifdef ENABLE_CONSISTENCY_CHECKS
 
       if(theitem == 0 || thekey == 0)
-         return MSGinconsistent("ClassSet");
+         return SPX_MSG_INCONSISTENT("ClassSet");
 
       if(thesize > themax || thenum > themax || thenum > thesize)
-         return MSGinconsistent("ClassSet");
+         return SPX_MSG_INCONSISTENT("ClassSet");
 
       if(thesize == thenum && firstfree != -themax - 1)
-         return MSGinconsistent("ClassSet");
+         return SPX_MSG_INCONSISTENT("ClassSet");
 
       if(thesize != thenum && firstfree == -themax - 1)
-         return MSGinconsistent("ClassSet");
+         return SPX_MSG_INCONSISTENT("ClassSet");
 
       for(int i = 0; i < thenum; ++i)
          if(theitem[thekey[i].idx].info != i)
-            return MSGinconsistent("ClassSet");
+            return SPX_MSG_INCONSISTENT("ClassSet");
 
 #endif
 
@@ -561,8 +558,8 @@ public:
    /// default constructor.
    explicit
    ClassSet(int pmax = 8)
-      : theitem(0)
-      , thekey(0)
+      : theitem(nullptr)
+      , thekey(nullptr)
       , themax(pmax < 1 ? 8 : pmax)
       , thesize(0)
       , thenum(0)
@@ -592,7 +589,7 @@ public:
    /// copy constructor.
    ClassSet(const ClassSet& old)
       : theitem(0)
-      , thekey(0)
+      , thekey(nullptr)
       , themax(old.themax)
       , thesize(old.thesize)
       , thenum(old.thenum)
